package
Version:
v0.8.0
Opens a new window with list of versions in this module.
Published: Jul 5, 2025
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
ChoiceAuto Choice = "auto"
ChoiceNone Choice = "none"
)
type Parameters struct {
Type string `json:"type"`
Properties Properties `json:"properties"`
Required []string `json:"required"`
}
type Property struct {
Type string `json:"type"`
Description string `json:"description,omitempty"`
Enum []any `json:"enum,omitempty"`
}
type Tool struct {
Type string `json:"type"`
Name string `json:"name"`
Description string `json:"description"`
Parameters Parameters `json:"parameters"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.